@@ -1,6 +1,7 @@
 import asyncio
 import json
 import logging
+import os
 import uuid
 from collections import defaultdict
 from pathlib import Path
@@ -29,6 +30,8 @@ from ...eval.models import EvaluationResult
 from ...eval.models.models import AgentExecution, EvalItemResult
 from .._runtime._contracts import (
     UiPathBaseRuntime,
+    UiPathErrorCategory,
+    UiPathErrorContract,
     UiPathExecutionBatchTraceProcessor,
     UiPathRuntimeContext,
     UiPathRuntimeFactory,
@@ -37,6 +40,7 @@ from .._runtime._contracts import (
 )
 from .._runtime._logging import ExecutionLogHandler
 from .._utils._eval_set import EvalHelpers
+from ..models.runtime_schema import Entrypoint
 from ._evaluator_factory import EvaluatorFactory
 from ._models._evaluation_set import (
     AnyEvaluationItem,
@@ -52,6 +56,7 @@ from ._models._output import (
     EvaluationRunResultDto,
     UiPathEvalOutput,
     UiPathEvalRunExecutionOutput,
+    convert_eval_execution_output_to_serializable,
 )
 from ._span_collection import ExecutionSpanCollector
 from .mocks.mocks import (
@@ -146,6 +151,8 @@ class UiPathEvalContext(UiPathRuntimeContext):
     workers: Optional[int] = 1
     eval_set: Optional[str] = None
     eval_ids: Optional[List[str]] = None
+    eval_set_run_id: Optional[str] = None
+    verbose: bool = False
 
 
 class UiPathEvalRuntime(UiPathBaseRuntime, Generic[T, C]):
@@ -172,6 +179,15 @@ class UiPathEvalRuntime(UiPathBaseRuntime, Generic[T, C]):
 
         self.logs_exporter: ExecutionLogsExporter = ExecutionLogsExporter()
         self.execution_id = str(uuid.uuid4())
+        self.entrypoint: Optional[Entrypoint] = None
+
+    async def get_entrypoint(self):
+        if not self.entrypoint:
+            temp_runtime = self.factory.new_runtime(
+                entrypoint=self.context.entrypoint, runtime_dir=os.getcwd()
+            )
+            self.entrypoint = await temp_runtime.get_entrypoint()
+        return self.entrypoint
 
     @classmethod
     def from_eval_context(
@@ -199,6 +215,7 @@ class UiPathEvalRuntime(UiPathBaseRuntime, Generic[T, C]):
             EvalSetRunCreatedEvent(
                 execution_id=self.execution_id,
                 entrypoint=self.context.entrypoint or "",
+                eval_set_run_id=self.context.eval_set_run_id,
                 eval_set_id=evaluation_set.id,
                 no_of_evals=len(evaluation_set.evaluations),
                 evaluators=evaluators,
@@ -330,6 +347,10 @@ class UiPathEvalRuntime(UiPathBaseRuntime, Generic[T, C]):
         evaluators: List[AnyEvaluator],
         event_bus: EventBus,
     ) -> EvaluationRunResult:
+        # Generate LLM-based input if input_mocking_strategy is defined
+        if eval_item.input_mocking_strategy:
+            eval_item = await self._generate_input_for_eval(eval_item)
+
         execution_id = str(uuid.uuid4())
 
         set_execution_context(eval_item, self.span_collector, execution_id)
@@ -347,7 +368,51 @@ class UiPathEvalRuntime(UiPathBaseRuntime, Generic[T, C]):
         )
 
         try:
-            agent_execution_output = await self.execute_runtime(eval_item, execution_id)
+            try:
+                agent_execution_output = await self.execute_runtime(
+                    eval_item, execution_id
+                )
+            except Exception as e:
+                if self.context.verbose:
+                    if isinstance(e, EvaluationRuntimeException):
+                        spans = e.spans
+                        logs = e.logs
+                        execution_time = e.execution_time
+                        loggable_error = e.root_exception
+                    else:
+                        spans = []
+                        logs = []
+                        execution_time = 0
+                        loggable_error = e
+
+                    error_info = UiPathErrorContract(
+                        code="RUNTIME_SHUTDOWN_ERROR",
+                        title="Runtime shutdown failed",
+                        detail=f"Error: {str(loggable_error)}",
+                        category=UiPathErrorCategory.UNKNOWN,
+                    )
+                    error_result = UiPathRuntimeResult(
+                        status=UiPathRuntimeStatus.FAULTED,
+                        error=error_info,
+                    )
+                    evaluation_run_results.agent_execution_output = (
+                        convert_eval_execution_output_to_serializable(
+                            UiPathEvalRunExecutionOutput(
+                                execution_time=execution_time,
+                                result=error_result,
+                                spans=spans,
+                                logs=logs,
+                            )
+                        )
+                    )
+                raise
+
+            if self.context.verbose:
+                evaluation_run_results.agent_execution_output = (
+                    convert_eval_execution_output_to_serializable(
+                        agent_execution_output
+                    )
+                )
             evaluation_item_results: list[EvalItemResult] = []
 
             for evaluator in evaluators:
@@ -462,12 +527,12 @@ class UiPathEvalRuntime(UiPathBaseRuntime, Generic[T, C]):
         return evaluation_run_results
 
     async def _generate_input_for_eval(
-        self, eval_item: EvaluationItem
-    ) -> EvaluationItem:
+        self, eval_item: AnyEvaluationItem
+    ) -> AnyEvaluationItem:
         """Use LLM to generate a mock input for an evaluation item."""
-        # TODO(bai): get the input schema from agent definition, once it is available there.
-        input_schema: dict[str, Any] = {}
-        generated_input = await generate_llm_input(eval_item, input_schema)
+        generated_input = await generate_llm_input(
+            eval_item, (await self.get_entrypoint()).input
+        )
         updated_eval_item = eval_item.model_copy(update={"inputs": generated_input})
         return updated_eval_item
 
@@ -507,6 +572,7 @@ class UiPathEvalRuntime(UiPathBaseRuntime, Generic[T, C]):
                 runtime_context, root_span=eval_item.name, attributes=attributes
             )
         except Exception as e:
+            end_time = time()
             spans, logs = self._get_and_clear_execution_data(
                 runtime_context.execution_id
             )
@@ -514,6 +580,7 @@ class UiPathEvalRuntime(UiPathBaseRuntime, Generic[T, C]):
                 spans=spans,
                 logs=logs,
                 root_exception=e,
+                execution_time=end_time - start_time,
             ) from e
 
         end_time = time()
