@@ -96,6 +96,7 @@ class UiPathErrorCategory(str, Enum):
 class UiPathErrorCode(str, Enum):
     """Standard error codes for UiPath runtime errors."""
 
+    AUTHENTICATION_REQUIRED = "AUTHENTICATION_REQUIRED"
     # Entrypoint related errors
     ENTRYPOINT_MISSING = "ENTRYPOINT_MISSING"
     ENTRYPOINT_NOT_FOUND = "ENTRYPOINT_NOT_FOUND"
@@ -382,7 +383,7 @@ class UiPathRuntimeContext(BaseModel):
     log_handler: Optional[logging.Handler] = None
     chat_handler: Optional[UiPathConversationHandler] = None
     is_conversational: Optional[bool] = None
-    breakpoints: Optional[List[str]] = None
+    breakpoints: Optional[List[str] | Literal["*"]] = None
 
     model_config = {"arbitrary_types_allowed": True, "extra": "allow"}
 
@@ -536,6 +537,7 @@ class UiPathRuntimeError(UiPathBaseRuntimeError):
         title: str,
         detail: str,
         category: UiPathErrorCategory = UiPathErrorCategory.UNKNOWN,
+        status: Optional[int] = None,
         prefix: str = "Python",
         include_traceback: bool = True,
     ):
@@ -544,6 +546,7 @@ class UiPathRuntimeError(UiPathBaseRuntimeError):
             title=title,
             detail=detail,
             category=category,
+            status=status,
             prefix=prefix,
             include_traceback=include_traceback,
         )
@@ -577,16 +580,14 @@ class UiPathBaseRuntime(ABC):
         runtime = cls(context)
         return runtime
 
-    @property
-    def get_binding_resources(self) -> List[BindingResource]:
+    async def get_binding_resources(self) -> List[BindingResource]:
         """Get binding resources for this runtime.
 
         Returns: A list of binding resources.
         """
         raise NotImplementedError()
 
-    @property
-    def get_entrypoint(self) -> Entrypoint:
+    async def get_entrypoint(self) -> Entrypoint:
         """Get entrypoint for this runtime.
 
         Returns: A entrypoint for this runtime.
