@@ -12,9 +12,9 @@ from uipath._cli._evals._runtime import (
     UiPathEvalContext,
 )
 from uipath._cli._runtime._runtime_factory import generate_runtime_factory
-from uipath._cli._utils._constants import UIPATH_PROJECT_ID
 from uipath._cli._utils._folders import get_personal_workspace_key_async
 from uipath._cli.middlewares import Middlewares
+from uipath._config import UiPathConfig
 from uipath._events._event_bus import EventBus
 from uipath.eval._helpers import auto_discover_entrypoint
 from uipath.tracing import LlmOpsHttpExporter
@@ -39,12 +39,13 @@ def setup_reporting_prereq(no_report: bool) -> bool:
     if no_report:
         return False
 
-    if not os.getenv(UIPATH_PROJECT_ID, False):
+    if not UiPathConfig.is_studio_project:
         console.warning(
             "UIPATH_PROJECT_ID environment variable not set. Results will no be reported to Studio Web."
         )
         return False
-    if not os.getenv("UIPATH_FOLDER_KEY"):
+
+    if not UiPathConfig.folder_key:
         folder_key = asyncio.run(get_personal_workspace_key_async())
         if folder_key:
             os.environ["UIPATH_FOLDER_KEY"] = folder_key
@@ -55,6 +56,12 @@ def setup_reporting_prereq(no_report: bool) -> bool:
 @click.argument("entrypoint", required=False)
 @click.argument("eval_set", required=False)
 @click.option("--eval-ids", cls=LiteralOption, default="[]")
+@click.option(
+    "--eval-set-run-id",
+    required=False,
+    type=str,
+    help="Custom evaluation set run ID (if not provided, a UUID will be generated)",
+)
 @click.option(
     "--no-report",
     is_flag=True,
@@ -78,6 +85,7 @@ def eval(
     entrypoint: Optional[str],
     eval_set: Optional[str],
     eval_ids: List[str],
+    eval_set_run_id: Optional[str],
     no_report: bool,
     workers: int,
     output_file: Optional[str],
@@ -88,6 +96,7 @@ def eval(
         entrypoint: Path to the agent script to evaluate (optional, will auto-discover if not specified)
         eval_set: Path to the evaluation set JSON file (optional, will auto-discover if not specified)
         eval_ids: Optional list of evaluation IDs
+        eval_set_run_id: Custom evaluation set run ID (optional, will generate UUID if not specified)
         workers: Number of parallel workers for running evaluations
         no_report: Do not report the evaluation results
     """
@@ -95,6 +104,7 @@ def eval(
         "entrypoint": entrypoint or auto_discover_entrypoint(),
         "eval_set": eval_set,
         "eval_ids": eval_ids,
+        "eval_set_run_id": eval_set_run_id,
         "workers": workers,
         "no_report": no_report,
         "output_file": output_file,
@@ -130,6 +140,7 @@ def eval(
 
         eval_context.no_report = no_report
         eval_context.workers = workers
+        eval_context.eval_set_run_id = eval_set_run_id
 
         # Load eval set to resolve the path
         eval_set_path = eval_set or EvalHelpers.auto_discover_eval_set()
