@@ -3,6 +3,9 @@ _CONNECTION_STRING = "InstrumentationKey=4128b5ed-f5ec-4612-ac32-b8cff0f2de93;In
 _APP_INSIGHTS_EVENT_MARKER_ATTRIBUTE = "APPLICATION_INSIGHTS_EVENT_MARKER_ATTRIBUTE"
 _OTEL_RESOURCE_ATTRIBUTES = "OTEL_RESOURCE_ATTRIBUTES"
 _SDK_VERSION = "SdkVersion"
+_PROJECT_KEY = "ProjectKey"
+
+_TELEMETRY_CONFIG_FILE = ".telemetry.json"
 
 _CODE_FILEPATH = "code.file.path"
 _CODE_FUNCTION = "code.function.name"
