@@ -2,7 +2,7 @@ import json
 import os
 from functools import wraps
 from importlib.metadata import version
-from logging import INFO, LogRecord, getLogger
+from logging import WARNING, LogRecord, getLogger
 from typing import Any, Callable, Dict, Optional, Union
 
 from azure.monitor.opentelemetry import configure_azure_monitor
@@ -95,14 +95,16 @@ class _TelemetryClient:
                 "service.name=uipath-sdk,service.instance.id=" + version("uipath")
             )
             os.environ["OTEL_TRACES_EXPORTER"] = "none"
+            os.environ["APPLICATIONINSIGHTS_STATSBEAT_DISABLED_ALL"] = "true"
 
             configure_azure_monitor(
                 connection_string=_CONNECTION_STRING,
                 disable_offline_storage=True,
             )
 
+            getLogger("azure").setLevel(WARNING)
             _logger.addHandler(_AzureMonitorOpenTelemetryEventHandler())
-            _logger.setLevel(INFO)
+            _logger.setLevel(WARNING)
 
             _TelemetryClient._initialized = True
         except Exception:
